@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2021-2024 null8626
+Copyright (c) 2021-2025 null8626
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -22,14 +22,14 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+from typing import Union
 from enum import Enum
-from typing import Union, Tuple
 
 from .constants import WIND_DIRECTION_EMOJIS
 
 
 class BasicEnum(Enum):
-  __slots__: Tuple[str, ...] = ()
+  __slots__: tuple[str, ...] = ()
 
   def __repr__(self) -> str:
     return f'{self.__class__.__name__}.{self.name}'
@@ -39,19 +39,25 @@ class BasicEnum(Enum):
 
 
 class IndexedEnum(Enum):
-  __slots__: Tuple[str, ...] = ('index',)
+  __slots__: tuple[str, ...] = ('index',)
 
   index: int
   """The index value."""
 
-  def __lt__(self, other: Union['IndexedEnum', int, float]) -> bool:
-    return self.index < getattr(other, 'index', other)
+  def __lt__(self, other: Union['IndexedEnum', float, int]) -> bool:
+    return float(self.index) < float(other)
 
-  def __eq__(self, other: Union['IndexedEnum', int, float]) -> bool:
-    return self.index == getattr(other, 'index', other)
+  def __le__(self, other: Union['IndexedEnum', float, int]) -> bool:
+    return float(self.index) <= float(other)
 
-  def __gt__(self, other: Union['IndexedEnum', int, float]) -> bool:
-    return self.index > getattr(other, 'index', other)
+  def __eq__(self, other: Union['IndexedEnum', float, int]) -> bool:
+    return float(self.index) == float(other)
+
+  def __gt__(self, other: Union['IndexedEnum', float, int]) -> bool:
+    return float(self.index) > float(other)
+
+  def __ge__(self, other: Union['IndexedEnum', float, int]) -> bool:
+    return float(self.index) >= float(other)
 
   def __hash__(self) -> int:
     return self.index
@@ -59,11 +65,14 @@ class IndexedEnum(Enum):
   def __int__(self) -> int:
     return self.index
 
+  def __float__(self) -> float:
+    return float(self.index)
+
 
 class HeatIndex(IndexedEnum):
-  """Represents a heat index."""
+  """A heat index."""
 
-  __slots__: Tuple[str, ...] = ()
+  __slots__: tuple[str, ...] = ()
 
   CAUTION = None
   EXTREME_CAUTION = None
@@ -89,9 +98,9 @@ class HeatIndex(IndexedEnum):
 
 
 class UltraViolet(BasicEnum, IndexedEnum):
-  """Represents ultra-violet (UV) index."""
+  """An ultra-violet (UV) index."""
 
-  __slots__: Tuple[str, ...] = ()
+  __slots__: tuple[str, ...] = ()
 
   LOW = None
   MODERATE = None
@@ -120,9 +129,9 @@ class UltraViolet(BasicEnum, IndexedEnum):
 
 
 class WindDirection(BasicEnum):
-  """Represents a wind direction."""
+  """A wind direction."""
 
-  __slots__: Tuple[str, ...] = ('degrees',)
+  __slots__: tuple[str, ...] = ('degrees',)
 
   NORTH = 'N'
   NORTH_NORTHEAST = 'NNE'
@@ -151,7 +160,7 @@ class WindDirection(BasicEnum):
     return enum
 
   def __contains__(self, other: Union['WindDirection', float, int]) -> bool:
-    other = getattr(other, 'degrees', other)
+    other = float(other)
 
     if self is self.NORTH:
       return other > 348.75 or other <= 11.25
@@ -194,15 +203,15 @@ class WindDirection(BasicEnum):
 
   @property
   def emoji(self) -> str:
-    """The emoji representing this enum."""
+    """Emoji representation."""
 
     return WIND_DIRECTION_EMOJIS[int(((self.degrees + 22.5) % 360) / 45.0)]
 
 
 class Locale(Enum):
-  """Represents the list of supported locales/languages by this library."""
+  """Supported locales/languages."""
 
-  __slots__: Tuple[str, ...] = ()
+  __slots__: tuple[str, ...] = ()
 
   AFRIKAANS = 'af'
   AMHARIC = 'am'
@@ -286,9 +295,9 @@ class Locale(Enum):
 
 
 class Kind(BasicEnum):
-  """Represents a weather forecast kind."""
+  """A weather forecast kind."""
 
-  __slots__: Tuple[str, ...] = ()
+  __slots__: tuple[str, ...] = ()
 
   SUNNY = 113
   PARTLY_CLOUDY = 116
@@ -338,7 +347,7 @@ class Kind(BasicEnum):
 
   @property
   def emoji(self) -> str:
-    """The emoji representing this enum."""
+    """Emoji representation."""
 
     if self is self.CLOUDY:
       return '☁️'
@@ -381,9 +390,9 @@ class Kind(BasicEnum):
 
 
 class Phase(BasicEnum):
-  """Represents a moon phase."""
+  """A moon phase."""
 
-  __slots__: Tuple[str, ...] = ()
+  __slots__: tuple[str, ...] = ()
 
   NEW_MOON = 'New Moon'
   WAXING_CRESCENT = 'Waxing Crescent'
@@ -396,7 +405,7 @@ class Phase(BasicEnum):
 
   @property
   def emoji(self) -> str:
-    """The stylized name for this enum."""
+    """Emoji representation."""
 
     if self is self.NEW_MOON:
       return '🌑'
